/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 99 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qstandarditemmodel.sip"
#include <qstandarditemmodel.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQStandardItem.cpp"

#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQStandardItem.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qicon.sip"
#include <qicon.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQStandardItem.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQStandardItem.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 44 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQStandardItem.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qbrush.sip"
#include <qbrush.h>
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQStandardItem.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQStandardItem.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfont.sip"
#include <qfont.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQStandardItem.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQStandardItem.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qdatastream.sip"
#include <qdatastream.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQStandardItem.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qstandarditemmodel.sip"
#include <qstandarditemmodel.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQStandardItem.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQStandardItem.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQStandardItem.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtGui/sipQtGuiQStandardItem.cpp"


class sipQStandardItem : public ::QStandardItem
{
public:
    sipQStandardItem();
    sipQStandardItem(const ::QString&);
    sipQStandardItem(const ::QIcon&, const ::QString&);
    sipQStandardItem(int, int);
    sipQStandardItem(const ::QStandardItem&);
    virtual ~sipQStandardItem();

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool operator<(const ::QStandardItem&) const SIP_OVERRIDE;
    void write(::QDataStream&) const SIP_OVERRIDE;
    void read(::QDataStream&) SIP_OVERRIDE;
    int type() const SIP_OVERRIDE;
    ::QStandardItem* clone() const SIP_OVERRIDE;
    void setData(const ::QVariant&, int) SIP_OVERRIDE;
    ::QVariant data(int) const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQStandardItem(const sipQStandardItem &);
    sipQStandardItem &operator = (const sipQStandardItem &);

    char sipPyMethods[7];
};

sipQStandardItem::sipQStandardItem(): ::QStandardItem(), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQStandardItem::sipQStandardItem(const ::QString& a0): ::QStandardItem(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQStandardItem::sipQStandardItem(const ::QIcon& a0, const ::QString& a1): ::QStandardItem(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQStandardItem::sipQStandardItem(int a0, int a1): ::QStandardItem(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQStandardItem::sipQStandardItem(const ::QStandardItem& a0): ::QStandardItem(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQStandardItem::~sipQStandardItem()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

bool sipQStandardItem::operator<(const ::QStandardItem& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName___lt__);

    if (!sipMeth)
        return ::QStandardItem::operator<(a0);

    extern bool sipVH_QtGui_152(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QStandardItem&);

    return sipVH_QtGui_152(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQStandardItem::write(::QDataStream& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_write);

    if (!sipMeth)
    {
        ::QStandardItem::write(a0);
        return;
    }

    extern void sipVH_QtGui_151(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDataStream&);

    sipVH_QtGui_151(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQStandardItem::read(::QDataStream& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_read);

    if (!sipMeth)
    {
        ::QStandardItem::read(a0);
        return;
    }

    extern void sipVH_QtGui_151(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDataStream&);

    sipVH_QtGui_151(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQStandardItem::type() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[3]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_type);

    if (!sipMeth)
        return ::QStandardItem::type();

    extern int sipVH_QtGui_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtGui_13(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QStandardItem* sipQStandardItem::clone() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[4]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_clone);

    if (!sipMeth)
        return ::QStandardItem::clone();

    extern ::QStandardItem* sipVH_QtGui_150(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtGui_150(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQStandardItem::setData(const ::QVariant& a0, int a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_setData);

    if (!sipMeth)
    {
        ::QStandardItem::setData(a0, a1);
        return;
    }

    extern void sipVH_QtGui_149(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QVariant&, int);

    sipVH_QtGui_149(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

::QVariant sipQStandardItem::data(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[6]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_data);

    if (!sipMeth)
        return ::QStandardItem::data(a0);

    extern ::QVariant sipVH_QtGui_148(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtGui_148(sipGILState, sipImportedVirtErrorHandlers_QtGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QStandardItem_data, "data(self, role: int = Qt.UserRole+1) -> Any");

extern "C" {static PyObject *meth_QStandardItem_data(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_data(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QStandardItem)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0 = Qt::UserRole+1;
        const ::QStandardItem *sipCpp;

        static const char *sipKwdList[] = {
            sipName_role,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|i", &sipSelf, sipType_QStandardItem, &sipCpp, &a0))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant((sipSelfWasArg ? sipCpp->::QStandardItem::data(a0) : sipCpp->data(a0)));

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_data, doc_QStandardItem_data);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_setData, "setData(self, value: Any, role: int = Qt.UserRole+1)");

extern "C" {static PyObject *meth_QStandardItem_setData(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_setData(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QStandardItem)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QVariant* a0;
        int a0State = 0;
        int a1 = Qt::UserRole+1;
        ::QStandardItem *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_role,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|i", &sipSelf, sipType_QStandardItem, &sipCpp, sipType_QVariant, &a0, &a0State, &a1))
        {
            (sipSelfWasArg ? sipCpp->::QStandardItem::setData(*a0, a1) : sipCpp->setData(*a0, a1));
            sipReleaseType(const_cast< ::QVariant *>(a0), sipType_QVariant, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_setData, doc_QStandardItem_setData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_text, "text(self) -> str");

extern "C" {static PyObject *meth_QStandardItem_text(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_text(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItem, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->text());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_text, doc_QStandardItem_text);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_icon, "icon(self) -> QIcon");

extern "C" {static PyObject *meth_QStandardItem_icon(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_icon(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItem, &sipCpp))
        {
            ::QIcon*sipRes;

            sipRes = new ::QIcon(sipCpp->icon());

            return sipConvertFromNewType(sipRes, sipType_QIcon, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_icon, doc_QStandardItem_icon);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_toolTip, "toolTip(self) -> str");

extern "C" {static PyObject *meth_QStandardItem_toolTip(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_toolTip(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItem, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toolTip());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_toolTip, doc_QStandardItem_toolTip);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_statusTip, "statusTip(self) -> str");

extern "C" {static PyObject *meth_QStandardItem_statusTip(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_statusTip(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItem, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->statusTip());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_statusTip, doc_QStandardItem_statusTip);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_whatsThis, "whatsThis(self) -> str");

extern "C" {static PyObject *meth_QStandardItem_whatsThis(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_whatsThis(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItem, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->whatsThis());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_whatsThis, doc_QStandardItem_whatsThis);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_sizeHint, "sizeHint(self) -> QSize");

extern "C" {static PyObject *meth_QStandardItem_sizeHint(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_sizeHint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItem, &sipCpp))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize(sipCpp->sizeHint());

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_sizeHint, doc_QStandardItem_sizeHint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_font, "font(self) -> QFont");

extern "C" {static PyObject *meth_QStandardItem_font(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_font(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItem, &sipCpp))
        {
            ::QFont*sipRes;

            sipRes = new ::QFont(sipCpp->font());

            return sipConvertFromNewType(sipRes, sipType_QFont, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_font, doc_QStandardItem_font);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_textAlignment, "textAlignment(self) -> Qt.AlignmentFlag");

extern "C" {static PyObject *meth_QStandardItem_textAlignment(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_textAlignment(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItem, &sipCpp))
        {
            ::Qt::Alignment*sipRes;

            sipRes = new ::Qt::Alignment(sipCpp->textAlignment());

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100Qt_AlignmentFlag, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_textAlignment, doc_QStandardItem_textAlignment);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_background, "background(self) -> QBrush");

extern "C" {static PyObject *meth_QStandardItem_background(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_background(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItem, &sipCpp))
        {
            ::QBrush*sipRes;

            sipRes = new ::QBrush(sipCpp->background());

            return sipConvertFromNewType(sipRes, sipType_QBrush, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_background, doc_QStandardItem_background);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_foreground, "foreground(self) -> QBrush");

extern "C" {static PyObject *meth_QStandardItem_foreground(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_foreground(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItem, &sipCpp))
        {
            ::QBrush*sipRes;

            sipRes = new ::QBrush(sipCpp->foreground());

            return sipConvertFromNewType(sipRes, sipType_QBrush, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_foreground, doc_QStandardItem_foreground);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_checkState, "checkState(self) -> Qt.CheckState");

extern "C" {static PyObject *meth_QStandardItem_checkState(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_checkState(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItem, &sipCpp))
        {
            ::Qt::CheckState sipRes;

            sipRes = sipCpp->checkState();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt_CheckState);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_checkState, doc_QStandardItem_checkState);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_accessibleText, "accessibleText(self) -> str");

extern "C" {static PyObject *meth_QStandardItem_accessibleText(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_accessibleText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItem, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->accessibleText());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_accessibleText, doc_QStandardItem_accessibleText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_accessibleDescription, "accessibleDescription(self) -> str");

extern "C" {static PyObject *meth_QStandardItem_accessibleDescription(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_accessibleDescription(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItem, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->accessibleDescription());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_accessibleDescription, doc_QStandardItem_accessibleDescription);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_flags, "flags(self) -> Qt.ItemFlag");

extern "C" {static PyObject *meth_QStandardItem_flags(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_flags(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItem, &sipCpp))
        {
            ::Qt::ItemFlags*sipRes;

            sipRes = new ::Qt::ItemFlags(sipCpp->flags());

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100Qt_ItemFlag, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_flags, doc_QStandardItem_flags);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_setFlags, "setFlags(self, flags: Qt.ItemFlag)");

extern "C" {static PyObject *meth_QStandardItem_setFlags(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_setFlags(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt::ItemFlags* a0;
        int a0State = 0;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QStandardItem, &sipCpp, sipType_QFlags_0100Qt_ItemFlag, &a0, &a0State))
        {
            sipCpp->setFlags(*a0);
            sipReleaseType(a0, sipType_QFlags_0100Qt_ItemFlag, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_setFlags, doc_QStandardItem_setFlags);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_isEnabled, "isEnabled(self) -> bool");

extern "C" {static PyObject *meth_QStandardItem_isEnabled(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_isEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItem, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isEnabled();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_isEnabled, doc_QStandardItem_isEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_setEnabled, "setEnabled(self, enabled: bool)");

extern "C" {static PyObject *meth_QStandardItem_setEnabled(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_setEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QStandardItem, &sipCpp, &a0))
        {
            sipCpp->setEnabled(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_setEnabled, doc_QStandardItem_setEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_isEditable, "isEditable(self) -> bool");

extern "C" {static PyObject *meth_QStandardItem_isEditable(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_isEditable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItem, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isEditable();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_isEditable, doc_QStandardItem_isEditable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_setEditable, "setEditable(self, editable: bool)");

extern "C" {static PyObject *meth_QStandardItem_setEditable(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_setEditable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QStandardItem, &sipCpp, &a0))
        {
            sipCpp->setEditable(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_setEditable, doc_QStandardItem_setEditable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_isSelectable, "isSelectable(self) -> bool");

extern "C" {static PyObject *meth_QStandardItem_isSelectable(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_isSelectable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItem, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isSelectable();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_isSelectable, doc_QStandardItem_isSelectable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_setSelectable, "setSelectable(self, selectable: bool)");

extern "C" {static PyObject *meth_QStandardItem_setSelectable(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_setSelectable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QStandardItem, &sipCpp, &a0))
        {
            sipCpp->setSelectable(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_setSelectable, doc_QStandardItem_setSelectable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_isCheckable, "isCheckable(self) -> bool");

extern "C" {static PyObject *meth_QStandardItem_isCheckable(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_isCheckable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItem, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isCheckable();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_isCheckable, doc_QStandardItem_isCheckable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_setCheckable, "setCheckable(self, checkable: bool)");

extern "C" {static PyObject *meth_QStandardItem_setCheckable(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_setCheckable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QStandardItem, &sipCpp, &a0))
        {
            sipCpp->setCheckable(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_setCheckable, doc_QStandardItem_setCheckable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_isDragEnabled, "isDragEnabled(self) -> bool");

extern "C" {static PyObject *meth_QStandardItem_isDragEnabled(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_isDragEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItem, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isDragEnabled();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_isDragEnabled, doc_QStandardItem_isDragEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_setDragEnabled, "setDragEnabled(self, dragEnabled: bool)");

extern "C" {static PyObject *meth_QStandardItem_setDragEnabled(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_setDragEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QStandardItem, &sipCpp, &a0))
        {
            sipCpp->setDragEnabled(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_setDragEnabled, doc_QStandardItem_setDragEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_isDropEnabled, "isDropEnabled(self) -> bool");

extern "C" {static PyObject *meth_QStandardItem_isDropEnabled(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_isDropEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItem, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isDropEnabled();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_isDropEnabled, doc_QStandardItem_isDropEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_setDropEnabled, "setDropEnabled(self, dropEnabled: bool)");

extern "C" {static PyObject *meth_QStandardItem_setDropEnabled(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_setDropEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QStandardItem, &sipCpp, &a0))
        {
            sipCpp->setDropEnabled(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_setDropEnabled, doc_QStandardItem_setDropEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_parent, "parent(self) -> QStandardItem|None");

extern "C" {static PyObject *meth_QStandardItem_parent(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_parent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItem, &sipCpp))
        {
            ::QStandardItem*sipRes;

            sipRes = sipCpp->parent();

            return sipConvertFromType(sipRes, sipType_QStandardItem, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_parent, doc_QStandardItem_parent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_row, "row(self) -> int");

extern "C" {static PyObject *meth_QStandardItem_row(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_row(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItem, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->row();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_row, doc_QStandardItem_row);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_column, "column(self) -> int");

extern "C" {static PyObject *meth_QStandardItem_column(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_column(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItem, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->column();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_column, doc_QStandardItem_column);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_index, "index(self) -> QModelIndex");

extern "C" {static PyObject *meth_QStandardItem_index(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_index(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItem, &sipCpp))
        {
            ::QModelIndex*sipRes;

            sipRes = new ::QModelIndex(sipCpp->index());

            return sipConvertFromNewType(sipRes, sipType_QModelIndex, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_index, doc_QStandardItem_index);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_model, "model(self) -> QStandardItemModel|None");

extern "C" {static PyObject *meth_QStandardItem_model(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_model(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItem, &sipCpp))
        {
            ::QStandardItemModel*sipRes;

            sipRes = sipCpp->model();

            return sipConvertFromType(sipRes, sipType_QStandardItemModel, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_model, doc_QStandardItem_model);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_rowCount, "rowCount(self) -> int");

extern "C" {static PyObject *meth_QStandardItem_rowCount(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_rowCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItem, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->rowCount();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_rowCount, doc_QStandardItem_rowCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_setRowCount, "setRowCount(self, rows: int)");

extern "C" {static PyObject *meth_QStandardItem_setRowCount(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_setRowCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QStandardItem, &sipCpp, &a0))
        {
            sipCpp->setRowCount(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_setRowCount, doc_QStandardItem_setRowCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_columnCount, "columnCount(self) -> int");

extern "C" {static PyObject *meth_QStandardItem_columnCount(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_columnCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItem, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->columnCount();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_columnCount, doc_QStandardItem_columnCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_setColumnCount, "setColumnCount(self, columns: int)");

extern "C" {static PyObject *meth_QStandardItem_setColumnCount(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_setColumnCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QStandardItem, &sipCpp, &a0))
        {
            sipCpp->setColumnCount(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_setColumnCount, doc_QStandardItem_setColumnCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_hasChildren, "hasChildren(self) -> bool");

extern "C" {static PyObject *meth_QStandardItem_hasChildren(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_hasChildren(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItem, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasChildren();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_hasChildren, doc_QStandardItem_hasChildren);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_child, "child(self, row: int, column: int = 0) -> QStandardItem|None");

extern "C" {static PyObject *meth_QStandardItem_child(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_child(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1 = 0;
        const ::QStandardItem *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_column,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bi|i", &sipSelf, sipType_QStandardItem, &sipCpp, &a0, &a1))
        {
            ::QStandardItem*sipRes;

            sipRes = sipCpp->child(a0, a1);

            return sipConvertFromType(sipRes, sipType_QStandardItem, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_child, doc_QStandardItem_child);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_setChild, "setChild(self, row: int, column: int, item: QStandardItem|None)\n"
"setChild(self, arow: int, aitem: QStandardItem|None)");

extern "C" {static PyObject *meth_QStandardItem_setChild(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_setChild(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        ::QStandardItem* a2;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiiJ:", &sipSelf, sipType_QStandardItem, &sipCpp, &a0, &a1, sipType_QStandardItem, &a2))
        {
            sipCpp->setChild(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        int a0;
        ::QStandardItem* a1;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ:", &sipSelf, sipType_QStandardItem, &sipCpp, &a0, sipType_QStandardItem, &a1))
        {
            sipCpp->setChild(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_setChild, doc_QStandardItem_setChild);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_insertRow, "insertRow(self, row: int, items: Iterable[QStandardItem])\n"
"insertRow(self, arow: int, aitem: QStandardItem|None)");

extern "C" {static PyObject *meth_QStandardItem_insertRow(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_insertRow(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const QList< ::QStandardItem*>* a1;
        int a1State = 0;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ3", &sipSelf, sipType_QStandardItem, &sipCpp, &a0, sipType_QList_0101QStandardItem, &a1, &a1State))
        {
            sipCpp->insertRow(a0, *a1);
            sipReleaseType(const_cast<QList< ::QStandardItem*> *>(a1), sipType_QList_0101QStandardItem, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        int a0;
        ::QStandardItem* a1;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ:", &sipSelf, sipType_QStandardItem, &sipCpp, &a0, sipType_QStandardItem, &a1))
        {
            sipCpp->insertRow(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_insertRow, doc_QStandardItem_insertRow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_insertRows, "insertRows(self, row: int, count: int)\n"
"insertRows(self, row: int, items: Iterable[QStandardItem])");

extern "C" {static PyObject *meth_QStandardItem_insertRows(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_insertRows(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QStandardItem, &sipCpp, &a0, &a1))
        {
            sipCpp->insertRows(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        int a0;
        const QList< ::QStandardItem*>* a1;
        int a1State = 0;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ3", &sipSelf, sipType_QStandardItem, &sipCpp, &a0, sipType_QList_0101QStandardItem, &a1, &a1State))
        {
            sipCpp->insertRows(a0, *a1);
            sipReleaseType(const_cast<QList< ::QStandardItem*> *>(a1), sipType_QList_0101QStandardItem, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_insertRows, doc_QStandardItem_insertRows);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_insertColumn, "insertColumn(self, column: int, items: Iterable[QStandardItem])");

extern "C" {static PyObject *meth_QStandardItem_insertColumn(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_insertColumn(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const QList< ::QStandardItem*>* a1;
        int a1State = 0;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ3", &sipSelf, sipType_QStandardItem, &sipCpp, &a0, sipType_QList_0101QStandardItem, &a1, &a1State))
        {
            sipCpp->insertColumn(a0, *a1);
            sipReleaseType(const_cast<QList< ::QStandardItem*> *>(a1), sipType_QList_0101QStandardItem, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_insertColumn, doc_QStandardItem_insertColumn);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_insertColumns, "insertColumns(self, column: int, count: int)");

extern "C" {static PyObject *meth_QStandardItem_insertColumns(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_insertColumns(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QStandardItem, &sipCpp, &a0, &a1))
        {
            sipCpp->insertColumns(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_insertColumns, doc_QStandardItem_insertColumns);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_removeRow, "removeRow(self, row: int)");

extern "C" {static PyObject *meth_QStandardItem_removeRow(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_removeRow(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QStandardItem, &sipCpp, &a0))
        {
            sipCpp->removeRow(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_removeRow, doc_QStandardItem_removeRow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_removeColumn, "removeColumn(self, column: int)");

extern "C" {static PyObject *meth_QStandardItem_removeColumn(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_removeColumn(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QStandardItem, &sipCpp, &a0))
        {
            sipCpp->removeColumn(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_removeColumn, doc_QStandardItem_removeColumn);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_removeRows, "removeRows(self, row: int, count: int)");

extern "C" {static PyObject *meth_QStandardItem_removeRows(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_removeRows(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QStandardItem, &sipCpp, &a0, &a1))
        {
            sipCpp->removeRows(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_removeRows, doc_QStandardItem_removeRows);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_removeColumns, "removeColumns(self, column: int, count: int)");

extern "C" {static PyObject *meth_QStandardItem_removeColumns(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_removeColumns(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QStandardItem, &sipCpp, &a0, &a1))
        {
            sipCpp->removeColumns(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_removeColumns, doc_QStandardItem_removeColumns);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_takeChild, "takeChild(self, row: int, column: int = 0) -> QStandardItem|None");

extern "C" {static PyObject *meth_QStandardItem_takeChild(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_takeChild(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1 = 0;
        ::QStandardItem *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_column,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bi|i", &sipSelf, sipType_QStandardItem, &sipCpp, &a0, &a1))
        {
            ::QStandardItem*sipRes;

            sipRes = sipCpp->takeChild(a0, a1);

            return sipConvertFromType(sipRes, sipType_QStandardItem, Py_None);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_takeChild, doc_QStandardItem_takeChild);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_takeRow, "takeRow(self, row: int) -> list[QStandardItem]");

extern "C" {static PyObject *meth_QStandardItem_takeRow(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_takeRow(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QStandardItem, &sipCpp, &a0))
        {
            QList< ::QStandardItem*>*sipRes;

            sipRes = new QList< ::QStandardItem*>(sipCpp->takeRow(a0));

            return sipConvertFromNewType(sipRes, sipType_QList_0101QStandardItem, Py_None);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_takeRow, doc_QStandardItem_takeRow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_takeColumn, "takeColumn(self, column: int) -> list[QStandardItem]");

extern "C" {static PyObject *meth_QStandardItem_takeColumn(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_takeColumn(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QStandardItem, &sipCpp, &a0))
        {
            QList< ::QStandardItem*>*sipRes;

            sipRes = new QList< ::QStandardItem*>(sipCpp->takeColumn(a0));

            return sipConvertFromNewType(sipRes, sipType_QList_0101QStandardItem, Py_None);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_takeColumn, doc_QStandardItem_takeColumn);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_sortChildren, "sortChildren(self, column: int, order: Qt.SortOrder = Qt.AscendingOrder)");

extern "C" {static PyObject *meth_QStandardItem_sortChildren(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_sortChildren(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::Qt::SortOrder a1 = Qt::AscendingOrder;
        ::QStandardItem *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_order,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bi|E", &sipSelf, sipType_QStandardItem, &sipCpp, &a0, sipType_Qt_SortOrder, &a1))
        {
            sipCpp->sortChildren(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_sortChildren, doc_QStandardItem_sortChildren);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_clone, "clone(self) -> QStandardItem|None");

extern "C" {static PyObject *meth_QStandardItem_clone(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_clone(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QStandardItem)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItem, &sipCpp))
        {
            ::QStandardItem*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QStandardItem::clone() : sipCpp->clone());

            return sipConvertFromType(sipRes, sipType_QStandardItem, Py_None);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_clone, doc_QStandardItem_clone);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_type, "type(self) -> int");

extern "C" {static PyObject *meth_QStandardItem_type(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_type(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QStandardItem)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItem, &sipCpp))
        {
            int sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QStandardItem::type() : sipCpp->type());

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_type, doc_QStandardItem_type);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_read, "read(self, in_: QDataStream)");

extern "C" {static PyObject *meth_QStandardItem_read(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_read(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QStandardItem)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QDataStream* a0;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QStandardItem, &sipCpp, sipType_QDataStream, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QStandardItem::read(*a0) : sipCpp->read(*a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_read, doc_QStandardItem_read);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_write, "write(self, out: QDataStream)");

extern "C" {static PyObject *meth_QStandardItem_write(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_write(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QStandardItem)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QDataStream* a0;
        const ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QStandardItem, &sipCpp, sipType_QDataStream, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QStandardItem::write(*a0) : sipCpp->write(*a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_write, doc_QStandardItem_write);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_setText, "setText(self, atext: str|None)");

extern "C" {static PyObject *meth_QStandardItem_setText(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_setText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QStandardItem, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setText(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_setText, doc_QStandardItem_setText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_setIcon, "setIcon(self, aicon: QIcon)");

extern "C" {static PyObject *meth_QStandardItem_setIcon(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_setIcon(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QIcon* a0;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QStandardItem, &sipCpp, sipType_QIcon, &a0))
        {
            sipCpp->setIcon(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_setIcon, doc_QStandardItem_setIcon);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_setToolTip, "setToolTip(self, atoolTip: str|None)");

extern "C" {static PyObject *meth_QStandardItem_setToolTip(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_setToolTip(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QStandardItem, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setToolTip(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_setToolTip, doc_QStandardItem_setToolTip);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_setStatusTip, "setStatusTip(self, astatusTip: str|None)");

extern "C" {static PyObject *meth_QStandardItem_setStatusTip(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_setStatusTip(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QStandardItem, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setStatusTip(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_setStatusTip, doc_QStandardItem_setStatusTip);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_setWhatsThis, "setWhatsThis(self, awhatsThis: str|None)");

extern "C" {static PyObject *meth_QStandardItem_setWhatsThis(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_setWhatsThis(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QStandardItem, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setWhatsThis(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_setWhatsThis, doc_QStandardItem_setWhatsThis);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_setSizeHint, "setSizeHint(self, asizeHint: QSize)");

extern "C" {static PyObject *meth_QStandardItem_setSizeHint(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_setSizeHint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSize* a0;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QStandardItem, &sipCpp, sipType_QSize, &a0))
        {
            sipCpp->setSizeHint(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_setSizeHint, doc_QStandardItem_setSizeHint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_setFont, "setFont(self, afont: QFont)");

extern "C" {static PyObject *meth_QStandardItem_setFont(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_setFont(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFont* a0;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QStandardItem, &sipCpp, sipType_QFont, &a0))
        {
            sipCpp->setFont(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_setFont, doc_QStandardItem_setFont);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_setTextAlignment, "setTextAlignment(self, atextAlignment: Qt.AlignmentFlag)");

extern "C" {static PyObject *meth_QStandardItem_setTextAlignment(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_setTextAlignment(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt::Alignment* a0;
        int a0State = 0;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QStandardItem, &sipCpp, sipType_QFlags_0100Qt_AlignmentFlag, &a0, &a0State))
        {
            sipCpp->setTextAlignment(*a0);
            sipReleaseType(a0, sipType_QFlags_0100Qt_AlignmentFlag, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_setTextAlignment, doc_QStandardItem_setTextAlignment);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_setBackground, "setBackground(self, abrush: QBrush|QColor|Qt.GlobalColor|int|QGradient)");

extern "C" {static PyObject *meth_QStandardItem_setBackground(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_setBackground(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBrush* a0;
        int a0State = 0;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QStandardItem, &sipCpp, sipType_QBrush, &a0, &a0State))
        {
            sipCpp->setBackground(*a0);
            sipReleaseType(const_cast< ::QBrush *>(a0), sipType_QBrush, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_setBackground, doc_QStandardItem_setBackground);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_setForeground, "setForeground(self, abrush: QBrush|QColor|Qt.GlobalColor|int|QGradient)");

extern "C" {static PyObject *meth_QStandardItem_setForeground(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_setForeground(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBrush* a0;
        int a0State = 0;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QStandardItem, &sipCpp, sipType_QBrush, &a0, &a0State))
        {
            sipCpp->setForeground(*a0);
            sipReleaseType(const_cast< ::QBrush *>(a0), sipType_QBrush, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_setForeground, doc_QStandardItem_setForeground);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_setCheckState, "setCheckState(self, acheckState: Qt.CheckState)");

extern "C" {static PyObject *meth_QStandardItem_setCheckState(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_setCheckState(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt::CheckState a0;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QStandardItem, &sipCpp, sipType_Qt_CheckState, &a0))
        {
            sipCpp->setCheckState(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_setCheckState, doc_QStandardItem_setCheckState);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_setAccessibleText, "setAccessibleText(self, aaccessibleText: str|None)");

extern "C" {static PyObject *meth_QStandardItem_setAccessibleText(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_setAccessibleText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QStandardItem, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setAccessibleText(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_setAccessibleText, doc_QStandardItem_setAccessibleText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_setAccessibleDescription, "setAccessibleDescription(self, aaccessibleDescription: str|None)");

extern "C" {static PyObject *meth_QStandardItem_setAccessibleDescription(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_setAccessibleDescription(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QStandardItem, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setAccessibleDescription(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_setAccessibleDescription, doc_QStandardItem_setAccessibleDescription);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_appendRow, "appendRow(self, items: Iterable[QStandardItem])\n"
"appendRow(self, aitem: QStandardItem|None)");

extern "C" {static PyObject *meth_QStandardItem_appendRow(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_appendRow(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QList< ::QStandardItem*>* a0;
        int a0State = 0;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ3", &sipSelf, sipType_QStandardItem, &sipCpp, sipType_QList_0101QStandardItem, &a0, &a0State))
        {
            sipCpp->appendRow(*a0);
            sipReleaseType(const_cast<QList< ::QStandardItem*> *>(a0), sipType_QList_0101QStandardItem, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QStandardItem* a0;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_QStandardItem, &sipCpp, sipType_QStandardItem, &a0))
        {
            sipCpp->appendRow(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_appendRow, doc_QStandardItem_appendRow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_appendColumn, "appendColumn(self, items: Iterable[QStandardItem])");

extern "C" {static PyObject *meth_QStandardItem_appendColumn(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_appendColumn(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QList< ::QStandardItem*>* a0;
        int a0State = 0;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ3", &sipSelf, sipType_QStandardItem, &sipCpp, sipType_QList_0101QStandardItem, &a0, &a0State))
        {
            sipCpp->appendColumn(*a0);
            sipReleaseType(const_cast<QList< ::QStandardItem*> *>(a0), sipType_QList_0101QStandardItem, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_appendColumn, doc_QStandardItem_appendColumn);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_appendRows, "appendRows(self, items: Iterable[QStandardItem])");

extern "C" {static PyObject *meth_QStandardItem_appendRows(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_appendRows(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QList< ::QStandardItem*>* a0;
        int a0State = 0;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ3", &sipSelf, sipType_QStandardItem, &sipCpp, sipType_QList_0101QStandardItem, &a0, &a0State))
        {
            sipCpp->appendRows(*a0);
            sipReleaseType(const_cast<QList< ::QStandardItem*> *>(a0), sipType_QList_0101QStandardItem, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_appendRows, doc_QStandardItem_appendRows);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_emitDataChanged, "emitDataChanged(self)");

extern "C" {static PyObject *meth_QStandardItem_emitDataChanged(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_emitDataChanged(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QStandardItem, &sipCpp))
        {
            sipCpp->emitDataChanged();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_emitDataChanged, doc_QStandardItem_emitDataChanged);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_isAutoTristate, "isAutoTristate(self) -> bool");

extern "C" {static PyObject *meth_QStandardItem_isAutoTristate(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_isAutoTristate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItem, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isAutoTristate();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_isAutoTristate, doc_QStandardItem_isAutoTristate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_setAutoTristate, "setAutoTristate(self, tristate: bool)");

extern "C" {static PyObject *meth_QStandardItem_setAutoTristate(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_setAutoTristate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QStandardItem, &sipCpp, &a0))
        {
            sipCpp->setAutoTristate(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_setAutoTristate, doc_QStandardItem_setAutoTristate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_isUserTristate, "isUserTristate(self) -> bool");

extern "C" {static PyObject *meth_QStandardItem_isUserTristate(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_isUserTristate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItem, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isUserTristate();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_isUserTristate, doc_QStandardItem_isUserTristate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_setUserTristate, "setUserTristate(self, tristate: bool)");

extern "C" {static PyObject *meth_QStandardItem_setUserTristate(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_setUserTristate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QStandardItem, &sipCpp, &a0))
        {
            sipCpp->setUserTristate(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_setUserTristate, doc_QStandardItem_setUserTristate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStandardItem_clearData, "clearData(self)");

extern "C" {static PyObject *meth_QStandardItem_clearData(PyObject *, PyObject *);}
static PyObject *meth_QStandardItem_clearData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QStandardItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStandardItem, &sipCpp))
        {
            sipCpp->clearData();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStandardItem, sipName_clearData, doc_QStandardItem_clearData);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QStandardItem___ge__(PyObject *, PyObject *);}
static PyObject *slot_QStandardItem___ge__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QStandardItem *sipCpp = reinterpret_cast< ::QStandardItem *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QStandardItem));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStandardItem* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QStandardItem, &a0))
        {
            bool sipRes;

            sipRes = !sipCpp->::QStandardItem::operator<(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtGui, ge_slot, sipType_QStandardItem, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QStandardItem___lt__(PyObject *, PyObject *);}
static PyObject *slot_QStandardItem___lt__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QStandardItem *sipCpp = reinterpret_cast< ::QStandardItem *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QStandardItem));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStandardItem* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QStandardItem, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QStandardItem::operator<(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtGui, lt_slot, sipType_QStandardItem, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QStandardItem(void *, int);}
static void release_QStandardItem(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQStandardItem *>(sipCppV);
    else
        delete reinterpret_cast< ::QStandardItem *>(sipCppV);
}


extern "C" {static void *array_QStandardItem(Py_ssize_t);}
static void *array_QStandardItem(Py_ssize_t sipNrElem)
{
    return new ::QStandardItem[sipNrElem];
}


extern "C" {static void array_delete_QStandardItem(void *);}
static void array_delete_QStandardItem(void *sipCpp)
{
    delete[] reinterpret_cast< ::QStandardItem *>(sipCpp);
}


extern "C" {static void assign_QStandardItem(void *, Py_ssize_t, void *);}
static void assign_QStandardItem(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QStandardItem *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QStandardItem *>(sipSrc);
}


extern "C" {static void *copy_QStandardItem(const void *, Py_ssize_t);}
static void *copy_QStandardItem(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QStandardItem(reinterpret_cast<const ::QStandardItem *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QStandardItem(sipSimpleWrapper *);}
static void dealloc_QStandardItem(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQStandardItem *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QStandardItem(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QStandardItem(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QStandardItem(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQStandardItem *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQStandardItem();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J1", sipType_QString, &a0, &a0State))
        {
            sipCpp = new sipQStandardItem(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QIcon* a0;
        const ::QString* a1;
        int a1State = 0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9J1", sipType_QIcon, &a0, sipType_QString, &a1, &a1State))
        {
            sipCpp = new sipQStandardItem(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        int a0;
        int a1 = 1;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_columns,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "i|i", &a0, &a1))
        {
            sipCpp = new sipQStandardItem(a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QStandardItem* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QStandardItem, &a0))
        {
            sipCpp = new sipQStandardItem(*a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QStandardItem[] = {
    {(void *)slot_QStandardItem___ge__, ge_slot},
    {(void *)slot_QStandardItem___lt__, lt_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QStandardItem[] = {
    {sipName_accessibleDescription, meth_QStandardItem_accessibleDescription, METH_VARARGS, doc_QStandardItem_accessibleDescription},
    {sipName_accessibleText, meth_QStandardItem_accessibleText, METH_VARARGS, doc_QStandardItem_accessibleText},
    {sipName_appendColumn, meth_QStandardItem_appendColumn, METH_VARARGS, doc_QStandardItem_appendColumn},
    {sipName_appendRow, meth_QStandardItem_appendRow, METH_VARARGS, doc_QStandardItem_appendRow},
    {sipName_appendRows, meth_QStandardItem_appendRows, METH_VARARGS, doc_QStandardItem_appendRows},
    {sipName_background, meth_QStandardItem_background, METH_VARARGS, doc_QStandardItem_background},
    {sipName_checkState, meth_QStandardItem_checkState, METH_VARARGS, doc_QStandardItem_checkState},
    {sipName_child, SIP_MLMETH_CAST(meth_QStandardItem_child), METH_VARARGS|METH_KEYWORDS, doc_QStandardItem_child},
    {sipName_clearData, meth_QStandardItem_clearData, METH_VARARGS, doc_QStandardItem_clearData},
    {sipName_clone, meth_QStandardItem_clone, METH_VARARGS, doc_QStandardItem_clone},
    {sipName_column, meth_QStandardItem_column, METH_VARARGS, doc_QStandardItem_column},
    {sipName_columnCount, meth_QStandardItem_columnCount, METH_VARARGS, doc_QStandardItem_columnCount},
    {sipName_data, SIP_MLMETH_CAST(meth_QStandardItem_data), METH_VARARGS|METH_KEYWORDS, doc_QStandardItem_data},
    {sipName_emitDataChanged, meth_QStandardItem_emitDataChanged, METH_VARARGS, doc_QStandardItem_emitDataChanged},
    {sipName_flags, meth_QStandardItem_flags, METH_VARARGS, doc_QStandardItem_flags},
    {sipName_font, meth_QStandardItem_font, METH_VARARGS, doc_QStandardItem_font},
    {sipName_foreground, meth_QStandardItem_foreground, METH_VARARGS, doc_QStandardItem_foreground},
    {sipName_hasChildren, meth_QStandardItem_hasChildren, METH_VARARGS, doc_QStandardItem_hasChildren},
    {sipName_icon, meth_QStandardItem_icon, METH_VARARGS, doc_QStandardItem_icon},
    {sipName_index, meth_QStandardItem_index, METH_VARARGS, doc_QStandardItem_index},
    {sipName_insertColumn, meth_QStandardItem_insertColumn, METH_VARARGS, doc_QStandardItem_insertColumn},
    {sipName_insertColumns, meth_QStandardItem_insertColumns, METH_VARARGS, doc_QStandardItem_insertColumns},
    {sipName_insertRow, meth_QStandardItem_insertRow, METH_VARARGS, doc_QStandardItem_insertRow},
    {sipName_insertRows, meth_QStandardItem_insertRows, METH_VARARGS, doc_QStandardItem_insertRows},
    {sipName_isAutoTristate, meth_QStandardItem_isAutoTristate, METH_VARARGS, doc_QStandardItem_isAutoTristate},
    {sipName_isCheckable, meth_QStandardItem_isCheckable, METH_VARARGS, doc_QStandardItem_isCheckable},
    {sipName_isDragEnabled, meth_QStandardItem_isDragEnabled, METH_VARARGS, doc_QStandardItem_isDragEnabled},
    {sipName_isDropEnabled, meth_QStandardItem_isDropEnabled, METH_VARARGS, doc_QStandardItem_isDropEnabled},
    {sipName_isEditable, meth_QStandardItem_isEditable, METH_VARARGS, doc_QStandardItem_isEditable},
    {sipName_isEnabled, meth_QStandardItem_isEnabled, METH_VARARGS, doc_QStandardItem_isEnabled},
    {sipName_isSelectable, meth_QStandardItem_isSelectable, METH_VARARGS, doc_QStandardItem_isSelectable},
    {sipName_isUserTristate, meth_QStandardItem_isUserTristate, METH_VARARGS, doc_QStandardItem_isUserTristate},
    {sipName_model, meth_QStandardItem_model, METH_VARARGS, doc_QStandardItem_model},
    {sipName_parent, meth_QStandardItem_parent, METH_VARARGS, doc_QStandardItem_parent},
    {sipName_read, meth_QStandardItem_read, METH_VARARGS, doc_QStandardItem_read},
    {sipName_removeColumn, meth_QStandardItem_removeColumn, METH_VARARGS, doc_QStandardItem_removeColumn},
    {sipName_removeColumns, meth_QStandardItem_removeColumns, METH_VARARGS, doc_QStandardItem_removeColumns},
    {sipName_removeRow, meth_QStandardItem_removeRow, METH_VARARGS, doc_QStandardItem_removeRow},
    {sipName_removeRows, meth_QStandardItem_removeRows, METH_VARARGS, doc_QStandardItem_removeRows},
    {sipName_row, meth_QStandardItem_row, METH_VARARGS, doc_QStandardItem_row},
    {sipName_rowCount, meth_QStandardItem_rowCount, METH_VARARGS, doc_QStandardItem_rowCount},
    {sipName_setAccessibleDescription, meth_QStandardItem_setAccessibleDescription, METH_VARARGS, doc_QStandardItem_setAccessibleDescription},
    {sipName_setAccessibleText, meth_QStandardItem_setAccessibleText, METH_VARARGS, doc_QStandardItem_setAccessibleText},
    {sipName_setAutoTristate, meth_QStandardItem_setAutoTristate, METH_VARARGS, doc_QStandardItem_setAutoTristate},
    {sipName_setBackground, meth_QStandardItem_setBackground, METH_VARARGS, doc_QStandardItem_setBackground},
    {sipName_setCheckState, meth_QStandardItem_setCheckState, METH_VARARGS, doc_QStandardItem_setCheckState},
    {sipName_setCheckable, meth_QStandardItem_setCheckable, METH_VARARGS, doc_QStandardItem_setCheckable},
    {sipName_setChild, meth_QStandardItem_setChild, METH_VARARGS, doc_QStandardItem_setChild},
    {sipName_setColumnCount, meth_QStandardItem_setColumnCount, METH_VARARGS, doc_QStandardItem_setColumnCount},
    {sipName_setData, SIP_MLMETH_CAST(meth_QStandardItem_setData), METH_VARARGS|METH_KEYWORDS, doc_QStandardItem_setData},
    {sipName_setDragEnabled, meth_QStandardItem_setDragEnabled, METH_VARARGS, doc_QStandardItem_setDragEnabled},
    {sipName_setDropEnabled, meth_QStandardItem_setDropEnabled, METH_VARARGS, doc_QStandardItem_setDropEnabled},
    {sipName_setEditable, meth_QStandardItem_setEditable, METH_VARARGS, doc_QStandardItem_setEditable},
    {sipName_setEnabled, meth_QStandardItem_setEnabled, METH_VARARGS, doc_QStandardItem_setEnabled},
    {sipName_setFlags, meth_QStandardItem_setFlags, METH_VARARGS, doc_QStandardItem_setFlags},
    {sipName_setFont, meth_QStandardItem_setFont, METH_VARARGS, doc_QStandardItem_setFont},
    {sipName_setForeground, meth_QStandardItem_setForeground, METH_VARARGS, doc_QStandardItem_setForeground},
    {sipName_setIcon, meth_QStandardItem_setIcon, METH_VARARGS, doc_QStandardItem_setIcon},
    {sipName_setRowCount, meth_QStandardItem_setRowCount, METH_VARARGS, doc_QStandardItem_setRowCount},
    {sipName_setSelectable, meth_QStandardItem_setSelectable, METH_VARARGS, doc_QStandardItem_setSelectable},
    {sipName_setSizeHint, meth_QStandardItem_setSizeHint, METH_VARARGS, doc_QStandardItem_setSizeHint},
    {sipName_setStatusTip, meth_QStandardItem_setStatusTip, METH_VARARGS, doc_QStandardItem_setStatusTip},
    {sipName_setText, meth_QStandardItem_setText, METH_VARARGS, doc_QStandardItem_setText},
    {sipName_setTextAlignment, meth_QStandardItem_setTextAlignment, METH_VARARGS, doc_QStandardItem_setTextAlignment},
    {sipName_setToolTip, meth_QStandardItem_setToolTip, METH_VARARGS, doc_QStandardItem_setToolTip},
    {sipName_setUserTristate, meth_QStandardItem_setUserTristate, METH_VARARGS, doc_QStandardItem_setUserTristate},
    {sipName_setWhatsThis, meth_QStandardItem_setWhatsThis, METH_VARARGS, doc_QStandardItem_setWhatsThis},
    {sipName_sizeHint, meth_QStandardItem_sizeHint, METH_VARARGS, doc_QStandardItem_sizeHint},
    {sipName_sortChildren, SIP_MLMETH_CAST(meth_QStandardItem_sortChildren), METH_VARARGS|METH_KEYWORDS, doc_QStandardItem_sortChildren},
    {sipName_statusTip, meth_QStandardItem_statusTip, METH_VARARGS, doc_QStandardItem_statusTip},
    {sipName_takeChild, SIP_MLMETH_CAST(meth_QStandardItem_takeChild), METH_VARARGS|METH_KEYWORDS, doc_QStandardItem_takeChild},
    {sipName_takeColumn, meth_QStandardItem_takeColumn, METH_VARARGS, doc_QStandardItem_takeColumn},
    {sipName_takeRow, meth_QStandardItem_takeRow, METH_VARARGS, doc_QStandardItem_takeRow},
    {sipName_text, meth_QStandardItem_text, METH_VARARGS, doc_QStandardItem_text},
    {sipName_textAlignment, meth_QStandardItem_textAlignment, METH_VARARGS, doc_QStandardItem_textAlignment},
    {sipName_toolTip, meth_QStandardItem_toolTip, METH_VARARGS, doc_QStandardItem_toolTip},
    {sipName_type, meth_QStandardItem_type, METH_VARARGS, doc_QStandardItem_type},
    {sipName_whatsThis, meth_QStandardItem_whatsThis, METH_VARARGS, doc_QStandardItem_whatsThis},
    {sipName_write, meth_QStandardItem_write, METH_VARARGS, doc_QStandardItem_write}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QStandardItem[] = {
    {sipName_Type, static_cast<int>(::QStandardItem::Type)},
    {sipName_UserType, static_cast<int>(::QStandardItem::UserType)},
    {0, 0}
};

PyDoc_STRVAR(doc_QStandardItem, "\1QStandardItem()\n"
"QStandardItem(text: str|None)\n"
"QStandardItem(icon: QIcon, text: str|None)\n"
"QStandardItem(rows: int, columns: int = 1)\n"
"QStandardItem(other: QStandardItem)");


sipClassTypeDef sipTypeDef_QtGui_QStandardItem = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QStandardItem,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QStandardItem,
        {0, 0, 1},
        79, methods_QStandardItem,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QStandardItem, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QStandardItem,
    -1,
    -1,
    SIP_NULLPTR,
    slots_QStandardItem,
    init_type_QStandardItem,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QStandardItem,
    assign_QStandardItem,
    array_QStandardItem,
    copy_QStandardItem,
    release_QStandardItem,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QStandardItem,
    sizeof (::QStandardItem),
};
